@@ -53,14 +53,14 @@ sub to_js_func ($self) {
         else {
             my $json;
 
-            if ( defined $item->[3] ) {
-                my $num = $item->[3];
+            if ( defined $item->[2] ) {
+                my $num = $item->[2];
 
-                local $item->[3] = P->uuid->v4_str;
+                local $item->[2] = P->uuid->v1mc_str;
 
                 $json = to_json($item)->$*;
 
-                $json =~ s/"$item->[3]"/$num/sm;
+                $json =~ s/"$item->[2]"/$num/sm;
             }
             else {
                 $json = to_json($item)->$*;
